<?php

namespace App\Http\Requests\API\File;

use App\Models\Enums\FileObjectType;
use App\Models\User;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\Rules\Enum;
use Illuminate\Validation\Rules\File;

class FileUploadRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array
    {
        $rules =  [
            "files.*" => [
                'required',
            ],

            "object_type" => [
                'required',
                new Enum(FileObjectType::class),
            ],
            "object_id" => [
                function ($attribute, $value, $fail) {
                    $exist = FileObjectType::from($this->get("object_type"))
                        ->modelBuilderAllowed($value,($this->get("is_action")==='0')?true : ($this->get("is_action") === '1' ? false : false))
                        ->where("company_id", Auth::user()->company_id)
                        ->where('id', $value)
                        ->count();
                    if (! $exist) {
                        $fail('Resources without permission to access.');
                    }
                }
            ],
            "source" => "in:1,2",
        ];

        $rules['file.*'][] = $this->get("source", 1) == 1
            ? File::types(['jpeg', 'png', 'gif'])->max("10mb")
            : File::types(['txt', 'jpeg', 'png', 'gif', 'pdf', 'xls', 'xlsx', 'zip', 'wps', 'docx', 'doc'])->max("2gb");

        return $rules;
    }
}
